@@ -1,7 +1,4 @@
-
 /*
- * $Id$
- *
  * Windows support
  * AUTHOR: Guido Serassio <serassio@squid-cache.org>
  * inspired by previous work by Romeo Anghelache & Eric Stern.
@@ -35,9 +32,9 @@
  */
 
 #include "squid.h"
-#include "squid_windows.h"
+#include "protos.h"
 
-#ifdef _SQUID_MSWIN_
+#if _SQUID_WINDOWS_
 #ifndef _MSWSOCK_
 #include <mswsock.h>
 #endif
@@ -47,6 +44,10 @@
 #endif
 #endif
 
+/* forward declarations */
+static void WIN32_Exit(void);
+static void WIN32_Abort(int);
+
 static unsigned int GetOSVersion();
 void WIN32_svcstatusupdate(DWORD, DWORD);
 void WINAPI WIN32_svcHandler(DWORD);
@@ -57,7 +58,6 @@ static void WIN32_build_argv (char *);
 #endif
 extern "C" void WINAPI SquidWinSvcMain(DWORD, char **);
 
-#if defined(_SQUID_MSWIN_)
 #if defined(_MSC_VER) /* Microsoft C Compiler ONLY */
 void Squid_Win32InvalidParameterHandler(const wchar_t*, const wchar_t*, const wchar_t*, unsigned int, uintptr_t);
 #endif
@@ -67,7 +67,6 @@ SQUIDCEXTERN LPCRITICAL_SECTION dbg_mutex;
 void WIN32_ExceptionHandlerCleanup(void);
 static int s_iInitCount = 0;
 static HANDLE NotifyAddrChange_thread = INVALID_HANDLE_VALUE;
-#endif /* _SQUID_MSWIN_ */
 
 static int Squid_Aborting = 0;
 
@@ -160,7 +159,7 @@ WIN32_create_key(void)
         }
 
         hKey = hKeyNext;
-        index++;
+        ++index;
     }
 
     if (keys[index] == NULL) {
@@ -268,7 +267,7 @@ static void WIN32_build_argv(char *cmd)
         /* Ignore spaces */
 
         if (xisspace(*cmd)) {
-            cmd++;
+            ++cmd;
             continue;
         }
 
@@ -276,7 +275,7 @@ static void WIN32_build_argv(char *cmd)
         word = cmd;
 
         while (*cmd) {
-            cmd++;		/* Skip over this character */
+            ++cmd;		/* Skip over this character */
 
             if (xisspace(*cmd))	/* End of argument if space */
                 break;
@@ -401,7 +400,6 @@ WIN32_Abort(int sig)
     WIN32_Exit();
 }
 
-#ifdef _SQUID_MSWIN_
 void
 WIN32_IpAddrChangeMonitorExit()
 {
@@ -412,14 +410,11 @@ WIN32_IpAddrChangeMonitorExit()
         CloseHandle(NotifyAddrChange_thread);
     }
 }
-#endif
 
 void
 WIN32_Exit()
 {
-#ifdef _SQUID_MSWIN_
     Win32SockCleanup();
-#endif
 #if USE_WIN32_SERVICE
 
     if (WIN32_run_mode == _WIN_SQUID_RUN_MODE_SERVICE) {
@@ -430,19 +425,14 @@ WIN32_Exit()
     }
 
 #endif
-#ifdef _SQUID_MSWIN_
     if (dbg_mutex)
         DeleteCriticalSection(dbg_mutex);
 
     WIN32_ExceptionHandlerCleanup();
     WIN32_IpAddrChangeMonitorExit();
-
-#endif
-
     _exit(0);
 }
 
-#ifdef _SQUID_MSWIN_
 static DWORD WINAPI
 WIN32_IpAddrChangeMonitor(LPVOID lpParam)
 {
@@ -457,10 +447,10 @@ WIN32_IpAddrChangeMonitor(LPVOID lpParam)
     while (1) {
         Result = NotifyAddrChange(NULL, NULL);
         if (Result != NO_ERROR) {
-            debugs(1, 1, "NotifyAddrChange error " << Result);
+            debugs(1, DBG_IMPORTANT, "NotifyAddrChange error " << Result);
             return 1;
         }
-        debugs(1, 1, "Notification of IP address change received, requesting Squid reconfiguration ...");
+        debugs(1, DBG_IMPORTANT, "Notification of IP address change received, requesting Squid reconfiguration ...");
         reconfigure(SIGHUP);
     }
     return 0;
@@ -478,13 +468,12 @@ WIN32_IpAddrChangeMonitorInit()
         if (NotifyAddrChange_thread == NULL) {
             status = GetLastError();
             NotifyAddrChange_thread = INVALID_HANDLE_VALUE;
-            debugs(1, 1, "Failed to start IP monitor thread.");
+            debugs(1, DBG_IMPORTANT, "Failed to start IP monitor thread.");
         } else
             debugs(1, 2, "Starting IP monitor thread [" << threadID << "] ...");
     }
     return status;
 }
-#endif /* _SQUID_MSWIN_ */
 
 int WIN32_Subsystem_Init(int * argc, char *** argv)
 {
@@ -580,20 +569,15 @@ int WIN32_Subsystem_Init(int * argc, char *** argv)
         svcStatus.dwCheckPoint = 0;
         svcStatus.dwWaitHint = 10000;
         SetServiceStatus(svcHandle, &svcStatus);
-#ifdef _SQUID_MSWIN_
 
         _setmaxstdio(Squid_MaxFD);
-#endif
 
     }
 
 #endif /* USE_WIN32_SERVICE */
-#ifdef _SQUID_MSWIN_
     if (Win32SockInit() < 0)
         return 1;
 
-#endif
-
     return 0;
 }
 
@@ -602,7 +586,7 @@ void
 WIN32_svcstatusupdate(DWORD svcstate, DWORD WaitHint)
 {
     if (WIN32_run_mode == _WIN_SQUID_RUN_MODE_SERVICE) {
-        svcStatus.dwCheckPoint++;
+        ++svcStatus.dwCheckPoint;
         svcStatus.dwWaitHint = WaitHint;
         svcStatus.dwCurrentState = svcstate;
         SetServiceStatus(svcHandle, &svcStatus);
@@ -628,10 +612,10 @@ WIN32_svcHandler(DWORD Opcode)
 
         if (!SetServiceStatus(svcHandle, &svcStatus)) {
             status = GetLastError();
-            debugs(1, 1, "SetServiceStatus error " << status);
+            debugs(1, DBG_IMPORTANT, "SetServiceStatus error " << status);
         }
 
-        debugs(1, 1, "Leaving Squid service");
+        debugs(1, DBG_IMPORTANT, "Leaving Squid service");
         return;
 
     case _WIN_SQUID_SERVICE_CONTROL_INTERROGATE:
@@ -639,7 +623,7 @@ WIN32_svcHandler(DWORD Opcode)
 
         if (!SetServiceStatus(svcHandle, &svcStatus)) {
             status = GetLastError();
-            debugs(1, 1, "SetServiceStatus error " << status);
+            debugs(1, DBG_IMPORTANT, "SetServiceStatus error " << status);
         }
 
         break;
@@ -666,14 +650,14 @@ WIN32_svcHandler(DWORD Opcode)
 
         if (!SetServiceStatus(svcHandle, &svcStatus)) {
             status = GetLastError();
-            debugs(1, 1, "SetServiceStatus error " << status);
+            debugs(1, DBG_IMPORTANT, "SetServiceStatus error " << status);
         }
 
-        debugs(1, 1, "Leaving Squid service");
+        debugs(1, DBG_IMPORTANT, "Leaving Squid service");
         break;
 
     default:
-        debugs(1, 1, "Unrecognized opcode " << Opcode);
+        debugs(1, DBG_IMPORTANT, "Unrecognized opcode " << Opcode);
     }
 
     return;
@@ -964,12 +948,8 @@ int main(int argc, char **argv)
         }
     } else {
         WIN32_run_mode = _WIN_SQUID_RUN_MODE_INTERACTIVE;
-#ifdef _SQUID_MSWIN_
-
         opt_no_daemon = 1;
 
-#endif
-
         return SquidMain(argc, argv);
     }
 
@@ -978,7 +958,6 @@ int main(int argc, char **argv)
 
 #endif /* USE_WIN32_SERVICE */
 
-#if defined(_SQUID_MSWIN_)
 static int Win32SockInit(void)
 {
     int iVersionRequested;
@@ -987,7 +966,7 @@ static int Win32SockInit(void)
     int optlen = sizeof(opt);
 
     if (s_iInitCount > 0) {
-        s_iInitCount++;
+        ++s_iInitCount;
         return (0);
     } else if (s_iInitCount < 0)
         return (s_iInitCount);
@@ -1026,7 +1005,7 @@ static int Win32SockInit(void)
     }
 
     WIN32_Socks_initialized = 1;
-    s_iInitCount++;
+    ++s_iInitCount;
     return (s_iInitCount);
 }
 
@@ -1042,5 +1021,3 @@ void Squid_Win32InvalidParameterHandler(const wchar_t* expression, const wchar_t
 {
     return;
 }
-
-#endif /* SQUID_MSWIN_ */
