@@ -38,6 +38,7 @@
 #include "comm.h"
 #include "comm/Connection.h"
 #include "comm/Loops.h"
+#include "compat/strsep.h"
 #include "event.h"
 #include "ip/Address.h"
 #include "md5.h"
@@ -66,7 +67,7 @@ static EVH wccp2AssignBuckets;
 #define WCCP2_MASK_ASSIGNMENT		0x01
 
 #define	WCCP2_NONE_SECURITY_LEN	0
-#define	WCCP2_MD5_SECURITY_LEN	SQUID_MD5_DIGEST_LENGTH // 16
+#define	WCCP2_MD5_SECURITY_LEN	16
 
 /* Useful defines */
 #define	WCCP2_NUMPORTS	8
@@ -572,7 +573,7 @@ wccp2_get_service_by_id(int service, int service_id) {
 static char
 wccp2_update_md5_security(char *password, char *ptr, char *packet, int len)
 {
-    uint8_t md5Digest[SQUID_MD5_DIGEST_LENGTH];
+    uint8_t md5_digest[16];
     char pwd[WCCP2_PASSWORD_LEN];
     SquidMD5_CTX M;
 
@@ -600,7 +601,7 @@ wccp2_update_md5_security(char *password, char *ptr, char *packet, int len)
      * including the WCCP message header. The WCCP security implementation
      * area should be zero'ed before calculating the MD5 hash.
      */
-    /* XXX eventually we should be able to kill md5Digest and blit it directly in */
+    /* XXX eventually we should be able to kill md5_digest and blit it directly in */
     memset(ws->security_implementation, 0, sizeof(ws->security_implementation));
 
     SquidMD5Init(&M);
@@ -609,9 +610,9 @@ wccp2_update_md5_security(char *password, char *ptr, char *packet, int len)
 
     SquidMD5Update(&M, packet, len);
 
-    SquidMD5Final(md5Digest, &M);
+    SquidMD5Final(md5_digest, &M);
 
-    memcpy(ws->security_implementation, md5Digest, sizeof(md5Digest));
+    memcpy(ws->security_implementation, md5_digest, sizeof(md5_digest));
 
     /* Finished! */
     return 1;
@@ -626,7 +627,7 @@ wccp2_check_security(struct wccp2_service_list_t *srv, char *security, char *pac
 {
 
     struct wccp2_security_md5_t *ws = (struct wccp2_security_md5_t *) security;
-    uint8_t md5Digest[SQUID_MD5_DIGEST_LENGTH], md5_challenge[SQUID_MD5_DIGEST_LENGTH];
+    uint8_t md5_digest[16], md5_challenge[16];
     char pwd[WCCP2_PASSWORD_LEN];
     SquidMD5_CTX M;
 
@@ -654,7 +655,7 @@ wccp2_check_security(struct wccp2_service_list_t *srv, char *security, char *pac
     pwd[sizeof(pwd) - 1] = '\0';
 
     /* Take a copy of the challenge: we need to NUL it before comparing */
-    memcpy(md5_challenge, ws->security_implementation, sizeof(md5_challenge));
+    memcpy(md5_challenge, ws->security_implementation, 16);
 
     memset(ws->security_implementation, 0, sizeof(ws->security_implementation));
 
@@ -664,9 +665,9 @@ wccp2_check_security(struct wccp2_service_list_t *srv, char *security, char *pac
 
     SquidMD5Update(&M, packet, len);
 
-    SquidMD5Final(md5Digest, &M);
+    SquidMD5Final(md5_digest, &M);
 
-    return (memcmp(md5Digest, md5_challenge, SQUID_MD5_DIGEST_LENGTH) == 0);
+    return (memcmp(md5_digest, md5_challenge, 16) == 0);
 }
 
 void
@@ -1171,13 +1172,14 @@ wccp2HandleUdp(int sock, void *not_used)
 
     /* FIXME INET6 : drop conversion boundary */
     Ip::Address from_tmp;
-    from_tmp.setIPv4();
 
     len = comm_udp_recvfrom(sock,
                             &wccp2_i_see_you,
                             WCCP_RESPONSE_SIZE,
                             0,
                             from_tmp);
+    /* FIXME INET6 : drop conversion boundary */
+    from_tmp.getSockAddr(from);
 
     if (len < 0)
         return;
@@ -1188,9 +1190,6 @@ wccp2HandleUdp(int sock, void *not_used)
     if (ntohl(wccp2_i_see_you.type) != WCCP2_I_SEE_YOU)
         return;
 
-    /* FIXME INET6 : drop conversion boundary */
-    from_tmp.getSockAddr(from);
-
     debugs(80, 3, "Incoming WCCPv2 I_SEE_YOU length " << ntohs(wccp2_i_see_you.length) << ".");
 
     /* Record the total data length */
@@ -2205,72 +2204,82 @@ check_null_wccp2_service(void *v)
 static int
 parse_wccp2_service_flags(char *flags)
 {
-    if (!flags)
-        return 0;
-
-    char *flag = flags;
+    char *tmp, *tmp2;
+    char *flag;
     int retflag = 0;
 
-    while (size_t len = strcspn(flag, ",")) {
+    if (!flags) {
+        return 0;
+    }
 
-        if (strncmp(flag, "src_ip_hash", len) == 0) {
+    tmp = xstrdup(flags);
+    tmp2 = tmp;
+
+    flag = strsep(&tmp2, ",");
+
+    while (flag) {
+        if (strcmp(flag, "src_ip_hash") == 0) {
             retflag |= WCCP2_SERVICE_SRC_IP_HASH;
-        } else if (strncmp(flag, "dst_ip_hash", len) == 0) {
+        } else if (strcmp(flag, "dst_ip_hash") == 0) {
             retflag |= WCCP2_SERVICE_DST_IP_HASH;
-        } else if (strncmp(flag, "source_port_hash", len) == 0) {
+        } else if (strcmp(flag, "source_port_hash") == 0) {
             retflag |= WCCP2_SERVICE_SRC_PORT_HASH;
-        } else if (strncmp(flag, "dst_port_hash", len) == 0) {
+        } else if (strcmp(flag, "dst_port_hash") == 0) {
             retflag |= WCCP2_SERVICE_DST_PORT_HASH;
-        } else if (strncmp(flag, "ports_source", len) == 0) {
+        } else if (strcmp(flag, "ports_source") == 0) {
             retflag |= WCCP2_SERVICE_PORTS_SOURCE;
-        } else if (strncmp(flag, "src_ip_alt_hash", len) == 0) {
+        } else if (strcmp(flag, "src_ip_alt_hash") == 0) {
             retflag |= WCCP2_SERVICE_SRC_IP_ALT_HASH;
-        } else if (strncmp(flag, "dst_ip_alt_hash", len) == 0) {
+        } else if (strcmp(flag, "dst_ip_alt_hash") == 0) {
             retflag |= WCCP2_SERVICE_DST_IP_ALT_HASH;
-        } else if (strncmp(flag, "src_port_alt_hash", len) == 0) {
+        } else if (strcmp(flag, "src_port_alt_hash") == 0) {
             retflag |= WCCP2_SERVICE_SRC_PORT_ALT_HASH;
-        } else if (strncmp(flag, "dst_port_alt_hash", len) == 0) {
+        } else if (strcmp(flag, "dst_port_alt_hash") == 0) {
             retflag |= WCCP2_SERVICE_DST_PORT_ALT_HASH;
         } else {
-            flag[len] = '\0';
             fatalf("Unknown wccp2 service flag: %s\n", flag);
         }
 
-        if (flag[len] == '\0')
-            break;
-
-        flag += len+1;
+        flag = strsep(&tmp2, ",");
     }
 
+    xfree(tmp);
     return retflag;
 }
 
 static void
 parse_wccp2_service_ports(char *options, int portlist[])
 {
+    int i = 0;
+    int p;
+    char *tmp, *tmp2, *port;
+
     if (!options) {
         return;
     }
 
-    int i = 0;
-    char *tmp = options;
+    tmp = xstrdup(options);
+    tmp2 = tmp;
 
-    while (size_t len = strcspn(tmp, ",")) {
-        if (i >= WCCP2_NUMPORTS) {
-            fatalf("parse_wccp2_service_ports: too many ports (maximum: 8) in list '%s'\n", options);
-        }
-        int p = xatoi(tmp);
+    port = strsep(&tmp2, ",");
+
+    while (port && i < WCCP2_NUMPORTS) {
+        p = xatoi(port);
 
         if (p < 1 || p > 65535) {
-            fatalf("parse_wccp2_service_ports: port value '%s' isn't valid (1..65535)\n", tmp);
+            fatalf("parse_wccp2_service_ports: port value '%s' isn't valid (1..65535)\n", port);
         }
 
         portlist[i] = p;
         ++i;
-        if (tmp[len] == '\0')
-            return;
-        tmp += len+1;
+        port = strsep(&tmp2, ",");
     }
+
+    if (i == WCCP2_NUMPORTS && port) {
+        fatalf("parse_wccp2_service_ports: too many ports (maximum: 8) in list '%s'\n", options);
+    }
+
+    xfree(tmp);
 }
 
 void
